@@ -1,11 +1,11 @@
 #!/usr/bin/perl
 
+use v5.14;
+use warnings;
+
 package ColourWidget;
 use base 'Tickit::Widget';
 
-use strict;
-use warnings;
-
 use Tickit;
 
 my $text = "Press 0 to 7 to change the colour of this text";
