@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2009-2022 -- leonerd@leonerd.org.uk
 
-package Tickit 0.73;
+package Tickit 0.74;
 
 use v5.14;
 use warnings;
@@ -437,6 +437,9 @@ previous callback for the same key. The code block is invoked as
 
    $code->( $tickit, $key )
 
+The C<$key> name is encoded as given by the C<str> accessor of
+C<Tickit::Event::Key> (see L<Tickit::Event> for detail).
+
 If C<$code> is missing or C<undef>, any existing callback is removed.
 
 As a convenience for the common application use case, the C<Ctrl-C> key is
